@@ -2,8 +2,6 @@
 import matplotlib.image as mpimg
 import numpy as np
 import cv2
-import pygame
-
 
 import matplotlib.pyplot as plt
 from mpl_toolkits.mplot3d import Axes3D
@@ -11,81 +9,10 @@ from scipy.spatial import ConvexHull
 # from scipy.spatial import Delaunay
 
 from voxelmap.annex import *
-import voxelmap.objviewer as viewer
 
 from scipy import ndimage 
 
 
-def resize_array(array, mult=(2,2,2), threshold=1):
-    '''Resizes a three-dimensional array by the three dim factors specified by `mult` tuple. 
-    Converts to sparse array of 0s and 1s   
-
-    Parameters
-    ----------
-    array : np.array(int,int,int)
-        array to resize
-    mult: tuple(float,float,float)
-        depth length width factors to resize array with. e.g 2,2,2 resizes array to double its size in all dims
-    threshold : float / iint
-        Threshold is minimum value to convert to 1 in binary array. 
-    '''
-    array = ndimage.zoom(array, (2,2,2))
-    crds_nonzero = np.argwhere(array > threshold)
-    array.fill(0)
-    for k in crds_nonzero:
-        array[tuple(k)] = 1
-
-    return array
-
-
-def random_kernel_convolve(array, kernel,random_bounds=(-10,10)):
-    '''Applies a three-dimensional convolution with a randomly-mutating `kernel` 
-    on a 3-D `array` which changes for every array site when random_bounds are set to tuple. 
-    If random_bounds are set to False, convolution occurs in constant mode for the specified kernel. 
-
-    Parameters
-    ----------
-    array : np.array(int,int,int)
-        array to convolve
-    kernel: np.array(int,int,int)
-        kernel to use for convolution. If random_bounds are set to tuple, only the kernel's shape is used to specify the random_kernels
-    random_bounds : tuple(int,int) OR bool
-        see above explanation.
-    '''
-    if random_bounds and kernel.shape[0]%2:	
-        new_array = np.zeros(array.shape)
-
-        array = np.pad(array,kernel.shape[0]//2)
-
-        k_z,k_y,k_x = kernel.shape
-        Z,Y,X = new_array.shape 
-        # adapted from: 
-        # https://towardsdatascience.com/tensorflow-for-computer-vision-how-to-implement-convolutions-from-scratch-in-python-609158c24f82
-        for k in range(Z):
-            for j in range(Y):
-                for i in range(X):
-                    sector = array[k:k+k_z, j:j+k_y, i:i+k_x]
-
-                    kernel = np.random.randint(*random_bounds,(k_z,k_y,k_x)) 
-                    new_array[k,j,i] = np.sum(np.multiply(sector, kernel))
-        return new_array
-
-    else:
-        return ndimage.convolve(array, kernel, mode='constant', cval=0.0)
-
-def roughen(array,kernel_level=1):
-    '''Makes a 3d array model rougher by a special convolution operation. Uses `voxelmap.random_kernel_convolve`.
-
-    Parameters
-    ----------
-    array : np.array(int,int,int)
-        array to `roughen up`
-    kernel_level: int
-        length scale (size) of random kernels used. The smallest scale (=1) gives the roughest transformation.
-    '''
-    kernel = np.zeros((kernel_level,kernel_level,kernel_level))
-    return random_kernel_convolve(array,kernel,(-1,2))
-
 def SectorHull(array, sector_dims, Z_here, Z_there, Y_here, Y_there, X_here, X_there,  
                 num_simplices, rel_depth, color='orange', trace_min=1, plot=True, ax=[]):
     '''SectorHull does ConvexHull on a specific 2-D sector of the selected image
@@ -102,10 +29,10 @@ def SectorHull(array, sector_dims, Z_here, Z_there, Y_here, Y_there, X_here, X_t
 
         hull = ConvexHull(points)
 
-        if plot: 
-            for s in hull.simplices:
-                s = np.append(s, s[0])  # Here we cycle back to the first coordinate
-                ax.plot(Y_here+points[s, 1],X_here+points[s, 0], Z_here+points[s, 2], color=color)
+        # if plot: 
+        #     for s in hull.simplices:
+        #         s = np.append(s, s[0])  # Here we cycle back to the first coordinate
+        #         ax.plot(Y_here+points[s, 1],X_here+points[s, 0], Z_here+points[s, 2], color=color)
 
         newsimplices = np.array([s + num_simplices for s in hull.simplices])
 
@@ -184,6 +111,27 @@ class Image:
 
         self.intensity = self.intensity.astype('int')  # floor-divide
 
+    def MeshView(self,wireframe=False,color='pink',alpha=0.5,background_color='#333333', viewport = [1024, 768]):
+        '''
+        MeshView: triangulated mesh view with PyVista 
+        Parameters
+        ----------
+        objfile: string
+            .obj file to process with MeshView [in GLOBAL function only]
+        wireframe: bool
+            Represent mesh as wireframe instead of solid polyhedron if True (default: False). 
+        color : string / hexadecimal
+            mesh color. default: 'pink'
+        alpha : float
+            opacity transparency range: 0 - 1.0. Default: 0.5
+        background_color : string / hexadecimal
+            color of background. default: 'pink'
+        viewport : (int,int)
+            viewport / screen (width, height) for display window (default: 80% your screen's width & height)
+        '''
+        mesh = pv.read(self.objfile)
+        mesh.plot(show_edges=True if wireframe else False, color=color,opacity=alpha,background=background_color,window_size = viewport)
+
     def ImageMap(self,depth=5):
         '''Map image to 3-D array 
 
@@ -230,6 +178,7 @@ class Image:
         plot: bool
             plots a preliminary 3-D triangulated image if True
         '''
+        self.make()
 
         matrix = self.intensity
 
@@ -237,9 +186,10 @@ class Image:
         W = matrix.shape[1]
 
         ax=[]
-        if plot:
-            fig = plt.figure(figsize=figsize)
-            ax = fig.add_subplot(111, projection="3d")
+
+        # if plot:
+        #     fig = plt.figure(figsize=figsize)
+        #     ax = fig.add_subplot(111, projection="3d")
 
         "multiple sectors"
         NUM = 0
@@ -270,12 +220,15 @@ class Image:
         self.objfile = out_file 
 
         if plot:
-            ax.set_title("{} Convex Hull segments".format(L_sectors**2),color="#D3D3D3")
-            ax.set_facecolor('#3e404e')
+            # ax.set_title("{} Convex Hull segments".format(L_sectors**2),color="#D3D3D3")
+            # ax.set_facecolor('#3e404e')
+
+            # set_axes_equal(ax)
+            # plt.axis('off')
+            # plt.show()
+
+            self.MeshView()
 
-            set_axes_equal(ax)
-            plt.axis('off')
-            plt.show()
 
     def MarchingMesh(self, voxel_depth=12, level=0,
                 spacing=(1., 1., 1.), gradient_direction='descent', step_size=1, 
@@ -335,16 +288,3 @@ class Image:
                 allow_degenerate=allow_degenerate, method=method, mask=mask,
                 plot=plot, figsize=figsize)
 
-
-    # viewport_default = (0.8*np.array(pygame.display.set_mode().get_rect()[2:]))
-    def MeshView(self, wireframe=False, viewport=(2048, 1152)):
-        '''MeshView: triangulated mesh view with OpenGL [ uses pygame ]
-
-        Parameters
-        ----------
-        wireframe: bool
-            Represent mesh as wireframe instead of solid polyhedron if True (default: False). 
-        viewport : (int,int)
-            viewport / screen (width, height) for display window (default: 80% your screen's width & height)
-        '''
-        viewer.objview(self.objfile, wireframe=wireframe, usemtl=False, viewport=viewport)
\ No newline at end of file
